@@ -43,8 +43,9 @@ struct _editor_data_t
 
   GtkWidget* autoAnswerButton;
   GtkWidget* disableProximityCheck;
+  GtkWidget* autoAnswerDelaySlider;
   GtkWidget* turnSpeakerOnButton;
-
+  GtkWidget* main_dialog;
   GtkWidget* vibratingCheckbutton;
 
   GtkListStore* ringingTone;
@@ -198,13 +199,13 @@ set_profile_tone_value(const gchar* tone, GtkWidget* button, GtkListStore* list_
 {
   GtkTreeIter iter;
   gchar* display_value = get_display_value(tone, list_store, &iter);
-  
-  if (strlen(display_value) > 29)
+
+  if(strlen(display_value) > 27)
   {
-    gchar* short_display_value = g_strndup(display_value, 29);
-    short_display_value[28] = '.';
-    short_display_value[27] = '.';
+    gchar* short_display_value = g_strndup(display_value, 27);
     short_display_value[26] = '.';
+    short_display_value[25] = '.';
+    short_display_value[24] = '.';
     hildon_button_set_value(HILDON_BUTTON(button), short_display_value);
     g_free(short_display_value);
   }
@@ -298,7 +299,7 @@ set_profile_values(const gchar* profile_name, editor_data_t* data)
     hildon_check_button_set_active(HILDON_CHECK_BUTTON(data->turnSpeakerOnButton), TRUE);
   else
     hildon_check_button_set_active(HILDON_CHECK_BUTTON(data->turnSpeakerOnButton), FALSE);
-
+  gtk_range_set_value(GTK_RANGE(data->autoAnswerDelaySlider), data->profile_data->auto_answer_delay);
   set_profile_status_icon_value(data);
 }
 
@@ -368,6 +369,7 @@ save_profile_values(const gchar* profile_name, editor_data_t* data)
   data->profile_data->autoanswer = hildon_check_button_get_active(HILDON_CHECK_BUTTON(data->autoAnswerButton));
   data->profile_data->disable_proximity_check = hildon_check_button_get_active(HILDON_CHECK_BUTTON(data->disableProximityCheck));
   data->profile_data->turn_speaker_on = hildon_check_button_get_active(HILDON_CHECK_BUTTON(data->turnSpeakerOnButton));
+  data->profile_data->auto_answer_delay = gtk_range_get_value(GTK_RANGE(data->autoAnswerDelaySlider));
   profilesx_store_profile_data(profile_name, data->profile_data);
 }
 
@@ -377,7 +379,7 @@ void add_tone_to_list_store(GtkButton* button, GtkWidget* selector)
   GtkWidget* parent = gtk_widget_get_toplevel(GTK_WIDGET(button));
   GtkListStore* list_store = GTK_LIST_STORE(hildon_touch_selector_get_model(HILDON_TOUCH_SELECTOR(selector), 0));
 										    
-  parent = gtk_widget_get_parent(parent);
+  //  parent = gtk_widget_get_parent(parent);
   dialog = hildon_file_chooser_dialog_new(GTK_WINDOW(parent),
 					  GTK_FILE_CHOOSER_ACTION_OPEN);
   g_object_set(dialog, "empty-text", dgettext("osso-profiles", "profi_va_select_object_no_sound_clips"), NULL);
@@ -458,9 +460,15 @@ show_tone_selector(GtkListStore* list_store, GtkWidget* button, GtkWidget* selec
 
   int sound_handler_id = g_signal_connect(selector, "changed", G_CALLBACK(play_sound_sample), data);
   GtkWidget* dialog = gtk_dialog_new_with_buttons(get_tone_selector_title(data, button),
-						  NULL,
+						  GTK_WINDOW(data->main_dialog),
 						  GTK_DIALOG_MODAL,
 						  NULL);
+  profilesx_dialog_size_changed(gdk_display_get_default_screen(gdk_display_get_default()),
+				dialog);
+  g_signal_connect(gdk_display_get_default_screen(gdk_display_get_default()), 
+		   "size-changed", 
+		   G_CALLBACK(profilesx_dialog_size_changed), dialog); 
+
   more_button = hildon_gtk_button_new(HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT);
   gtk_button_set_label(GTK_BUTTON(more_button), dgettext("hildon-libs", "wdgt_bd_add"));
   gtk_container_add(GTK_CONTAINER(gtk_dialog_get_action_area(GTK_DIALOG(dialog))), more_button);
@@ -686,7 +694,7 @@ icon_selection_dialog(GtkButton* button, editor_data_t* app_data)
   const gchar* icon_name_loud = "statusarea_profilesx_loud";
 
   GtkWidget* dialog = gtk_dialog_new_with_buttons("Statusbar icon",
-						  NULL,
+						  GTK_WINDOW(app_data->main_dialog),
 						  GTK_DIALOG_MODAL,
 						  dgettext("hildon-libs", "wdgt_bd_save"),
 						  GTK_RESPONSE_OK,
@@ -809,7 +817,7 @@ layout_dialog_widgets(const gchar* profile_name, editor_data_t* data, GtkWidget*
   GtkWidget* imBox = gtk_hbox_new(TRUE, 0);
   GtkWidget* emailBox = gtk_hbox_new(TRUE, 0);
   GtkWidget* icon_label = gtk_label_new("Statusbar icon");
-
+  GtkWidget* auto_answer_box = gtk_vbox_new(TRUE, 0);
 
   gtk_box_pack_start(GTK_BOX(iconBox), icon_label, TRUE, TRUE, 0); 
   gtk_box_pack_end(GTK_BOX(iconBox), data->iconButton, TRUE, TRUE, 0); 
@@ -838,11 +846,16 @@ layout_dialog_widgets(const gchar* profile_name, editor_data_t* data, GtkWidget*
     gtk_box_pack_start(GTK_BOX(content_area), data->keypadsoundLevelButton, TRUE, FALSE, 0);
     gtk_box_pack_start(GTK_BOX(content_area), data->touchscreensoundLevelButton, TRUE, FALSE, 0);
     gtk_box_pack_start(GTK_BOX(content_area), data->autoAnswerButton, TRUE, FALSE, 0);
-    gtk_box_pack_start(GTK_BOX(content_area), data->disableProximityCheck, TRUE, FALSE, 0);
-    g_signal_connect(data->autoAnswerButton, "toggled", G_CALLBACK(_enable_disable_proximity_check), data->disableProximityCheck);
+    gtk_box_pack_start(GTK_BOX(auto_answer_box), data->autoAnswerDelaySlider, TRUE, FALSE, 0);
+    gtk_box_pack_start(GTK_BOX(auto_answer_box), data->disableProximityCheck, TRUE, FALSE, 0);
+    gtk_box_pack_start(GTK_BOX(content_area), auto_answer_box, TRUE, TRUE, 0);
+    g_signal_connect(data->autoAnswerButton, "toggled", G_CALLBACK(_enable_disable_proximity_check), auto_answer_box);
+    if(!hildon_check_button_get_active(HILDON_CHECK_BUTTON(data->autoAnswerButton)))
+      gtk_widget_set_sensitive(auto_answer_box, FALSE);
     gtk_box_pack_start(GTK_BOX(content_area), data->turnSpeakerOnButton, TRUE, FALSE, 0);
     pannable_area = hildon_pannable_area_new();
     hildon_pannable_area_add_with_viewport(HILDON_PANNABLE_AREA(pannable_area), content_area);
+    g_object_set(pannable_area, "hscrollbar-policy", GTK_POLICY_NEVER, NULL);
     gtk_container_add(GTK_CONTAINER(gtk_dialog_get_content_area(GTK_DIALOG(dialog))),
 		      pannable_area);
   }
@@ -857,6 +870,14 @@ layout_dialog_widgets(const gchar* profile_name, editor_data_t* data, GtkWidget*
   }
 }
 
+gchar*
+_format_autoanswerdelay_value(GtkScale* scale,
+			      double value,
+			      gpointer user_data)
+{
+  return g_strdup_printf("%0.*g seconds", gtk_scale_get_digits(scale), value);
+}
+
 static void 
 init_editor_dialog_widgets(editor_data_t* data)
 {
@@ -897,6 +918,11 @@ init_editor_dialog_widgets(editor_data_t* data)
   gtk_button_set_label(GTK_BUTTON(data->disableProximityCheck), "Disable Proximity Check");
   hildon_check_button_set_active(HILDON_CHECK_BUTTON(data->disableProximityCheck), FALSE);
   data->turnSpeakerOnButton = hildon_check_button_new(HILDON_SIZE_FINGER_HEIGHT);
+  data->autoAnswerDelaySlider = hildon_gtk_hscale_new();
+  gtk_range_set_range(GTK_RANGE(data->autoAnswerDelaySlider), 1, 6);
+  gtk_scale_set_digits(GTK_SCALE(data->autoAnswerDelaySlider), 0);
+  gtk_scale_set_draw_value(GTK_SCALE(data->autoAnswerDelaySlider), TRUE);
+  g_signal_connect(data->autoAnswerDelaySlider, "format-value", G_CALLBACK(_format_autoanswerdelay_value), NULL);
   gtk_button_set_label(GTK_BUTTON(data->turnSpeakerOnButton), 
 		       dgettext("rtcom-call-ui", "call_fi_call_handling_speaker"));
   hildon_check_button_set_active(HILDON_CHECK_BUTTON(data->turnSpeakerOnButton), FALSE);
@@ -908,6 +934,7 @@ show_editor_dialog(const gchar* profile_name, GtkWidget* main_dialog, GstElement
   GtkWidget* dialog;
   editor_data_t* data = g_new0(editor_data_t, 1);
   data->profile_data = g_new0(profilesx_profile_data, 1);
+  data->main_dialog = main_dialog;
   profilesx_load_profile_data(profile_name,
 			      data->profile_data);
   dialog = gtk_dialog_new_with_buttons(get_profile_display_name(profile_name),
@@ -915,7 +942,12 @@ show_editor_dialog(const gchar* profile_name, GtkWidget* main_dialog, GstElement
 				       GTK_DIALOG_MODAL,
 				       dgettext("hildon-libs", "wdgt_bd_save"), GTK_RESPONSE_OK,
 				       NULL);
-  gtk_window_set_default_size(GTK_WINDOW(dialog), -1, 300);  
+  profilesx_dialog_size_changed(gdk_display_get_default_screen(gdk_display_get_default()),
+				dialog);
+  g_signal_connect(gdk_display_get_default_screen(gdk_display_get_default()), 
+		   "size-changed", 
+		   G_CALLBACK(profilesx_dialog_size_changed), dialog); 
+
   init_editor_dialog_widgets(data);
   set_profile_values(profile_name, data);
   data->sound_player = sound_player;
