@@ -63,6 +63,7 @@ struct _ProfilesxStatusPluginPrivate
   DBusGProxy *dbus_system_proxy;
   guint gconf_notify_handler;
   gboolean autoanswer;
+  gint auto_answer_delay;
   gboolean turn_speaker_on;
   gboolean disable_proximity_check;
 };
@@ -266,6 +267,7 @@ static gboolean
 answer_call(gpointer user_data)
 {
   ProfilesxStatusPlugin* plugin = PROFILESX_STATUS_PLUGIN(user_data);
+  g_warning("answer call %d\n", plugin->priv->auto_answer_delay);
   if(plugin->priv->disable_proximity_check || !is_proximity_covered())
   {
     if(plugin->priv->dbus_system_conn)
@@ -294,7 +296,7 @@ handle_incoming_call(DBusGProxy *object,
   ProfilesxStatusPlugin* plugin = PROFILESX_STATUS_PLUGIN(user_data);
   if(g_strcmp0(state, "ringing") == 0 && plugin->priv->autoanswer)
   {
-    g_timeout_add_seconds(2, answer_call, plugin);
+    g_timeout_add_seconds(plugin->priv->auto_answer_delay+1, answer_call, plugin);
   }
   if(g_strcmp0(state, "active") == 0 && plugin->priv->turn_speaker_on)
   {
@@ -377,16 +379,19 @@ read_profile_gconf_options(ProfilesxStatusPlugin* plugin, const gchar* profile)
   gchar* autoanswer_conf_key = g_strdup_printf("%s/%s/autoAnswer", GC_ROOT, profile_name_key);
   gchar* disable_proximity_check_conf_key = g_strdup_printf("%s/%s/disableProximityCheck", GC_ROOT, profile_name_key);
   gchar* turnspeakeron_conf_key = g_strdup_printf("%s/%s/turnSpeakerOn", GC_ROOT, profile_name_key);
+  gchar* autoanswerdelay_conf_key = g_strdup_printf("%s/%s/autoanswerdelay", GC_ROOT, profile_name_key);
 
   plugin->priv->autoanswer = gconf_client_get_bool(client, autoanswer_conf_key, NULL);
   plugin->priv->disable_proximity_check = gconf_client_get_bool(client, disable_proximity_check_conf_key, NULL);
   plugin->priv->turn_speaker_on = gconf_client_get_bool(client, turnspeakeron_conf_key, NULL);
+  plugin->priv->auto_answer_delay = gconf_client_get_int(client, autoanswerdelay_conf_key, NULL);
 
   register_unregister_on_call(plugin);
   g_free(turnspeakeron_conf_key);
   g_free(autoanswer_conf_key);
   g_free(disable_proximity_check_conf_key);
   g_free(profile_name_key);
+  g_free(autoanswerdelay_conf_key);
   g_object_unref(client);
 }
 
@@ -614,6 +619,7 @@ profilesx_status_plugin_init(ProfilesxStatusPlugin* plugin)
   plugin->priv->autoanswer = FALSE;
   plugin->priv->disable_proximity_check = FALSE;
   plugin->priv->turn_speaker_on = FALSE;
+  plugin->priv->auto_answer_delay = 1;
   plugin->priv->gconf_notify_handler = 0;
   plugin->priv->dbus_system_conn = NULL;
   plugin->priv->dbus_system_proxy = NULL;
